@@ -11,19 +11,19 @@ class Drawer:
         self._base_message = base_message
         self._message = _MessageManager(base_message)
         self.config = config
-
         self._draw_message()
 
-    def _detect_format_attribute(self, record_attribute: str):
+    @staticmethod
+    def _detect_format_attribute(record_attribute: str, base_format_message: str):
         record_attribute = f"%({record_attribute})"
-        index = self._base_message.find(record_attribute)
+        index = base_format_message.find(record_attribute)
         if index == -1:
             return record_attribute
         base_index = index + len(record_attribute)
-        _len = len(self._base_message)
+        _len = len(base_format_message)
         while base_index < _len:
-            if self._base_message[base_index] in BASE_CHARS:
-                record_attribute += self._base_message[base_index]
+            if base_format_message[base_index] in BASE_CHARS:
+                record_attribute += base_format_message[base_index]
                 base_index += 1
             else:
                 break
@@ -32,20 +32,20 @@ class Drawer:
     def _draw_message(self):
         if self.config is not None:
             for item in self.config:
-                _temp_message = self._base_message
-                for key in item['config']:
-                    attribute_maker = self._detect_format_attribute(key)
-                    new_attribute_maker = attribute_maker
-                    _config = item['config'][key]
-                    for _item_config in _config:
-                        new_attribute_maker = get_color(_item_config) + new_attribute_maker + get_color(ColorMode.RESET)
-                    _temp_message = _temp_message.replace(attribute_maker, new_attribute_maker)
                 for _level in item['level']:
                     if _level not in level_to_names:
                         raise NotFoundLevel(_level)
                     str_level = level_to_names[_level]
-                    if str_level is not None:
-                        self._message.set_message(str_level, _temp_message)
+                    _temp_message = self._message.get_message(str_level)
+                    for key in item['config']:
+                        attribute_maker = self._detect_format_attribute(key, _temp_message)
+                        new_attribute_maker = attribute_maker
+                        _config = item['config'][key]
+                        for _item_config in _config:
+                            new_attribute_maker = get_color(_item_config) + new_attribute_maker + get_color(
+                                ColorMode.RESET)
+                        _temp_message = _temp_message.replace(attribute_maker, new_attribute_maker)
+                    self._message.set_message(str_level, _temp_message)
 
     def get_message(self, level=None):
         if level is None:
